@@ -1,6 +1,7 @@
 #' Is Incomplete Terms
 #'
 #' Tests whether a term vector has absent elements.
+#' The vector should not require repairing.
 #'
 #' @inheritParams params
 #' @return A logical scalar indicating whether the object's terms are incomplete.
@@ -8,19 +9,18 @@
 #' @export
 #'
 #' @examples
-#' is.incomplete_terms(as.term("b[2]"))
-#' is.incomplete_terms(as.term(c("b[2]", "b[1]")))
-is.incomplete_terms <- function(x, ...) UseMethod("is.incomplete_terms")
-
-#' @describeIn is.incomplete_terms Test whether a term vector is incomplete
-#' @export
-is.incomplete_terms.term <- function(x, ...) {
+#' is_incomplete_terms(term("b[2]"))
+#' is_incomplete_terms(term("b[2]", "b[1]"))
+#' is_incomplete_terms(term("b[2]", "b[1]", "b[1]"))
+is_incomplete_terms <- function(x, ...) {
   if (!length(x)) {
     return(FALSE)
   }
   if (anyNA(x)) {
     return(NA)
   }
+  if(length(unique(table(x))) != 1L)
+    return(TRUE)
   x <- unique(x)
   length(x) < sum(vapply(pdims(x), prod, 1))
 }
